/***************************************************************************
 *   Copyright (C) 2008 by Lisandro Damián Nicanor Pérez Meyer             *
 *   perezmeyer@gmail.com                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "dataholder.h"

#include <QList>
#include <QDebug>

DataHolder::DataHolder(int rows, int columns)
{
	numberOfRows = rows;
	numberOfColumns = columns;
	matrix = new Point4F[rows * columns];
}

DataHolder::~DataHolder()
{
	delete [] matrix;
}

void DataHolder::addData(int row, int column, const Point4F & data)
{
	if(row < 0 || row >= numberOfRows)
	{
		qDebug() << "DataHolder::addData. row is out of bounds. It's value is " << row;
		return;
	}
	if(column < 0 || row >= numberOfColumns)
	{
		qDebug() << "DataHolder::addData. column is out of bounds. It's value is " << column;
		return;
	}
	matrix[row * numberOfColumns + column] = data;
}

QVector<double> * DataHolder::getVertexArray(int row)
{
	if(row < 0 || row >= numberOfRows -1)
	{
		qDebug() << "DataHolder::getVertexArray, row is out of bounds. It's value is " << row;
		return 0;
	}

	QVector<double> * va = new QVector<double>;

		for(int column=0; column < numberOfColumns; column++)
		{
			va->append(matrix[row * numberOfColumns + column].x());
			va->append(matrix[row * numberOfColumns + column].y());
			va->append(matrix[row * numberOfColumns + column].z());

			va->append(matrix[(row + 1) * numberOfColumns + column].x());
			va->append(matrix[(row + 1) * numberOfColumns + column].y());
			va->append(matrix[(row + 1) * numberOfColumns + column].z());
		}

	return va;
}

